==> goods-center-api-2.4.14-SNAPSHOT-fxr-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/sku/AttributeLibraryDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.sku;

import java.util.Date;
import java.util.List;

/**
 * @ClassName: AttributeLibraryDto
 * @Description: 商品属性库（属性名）
 * @author: fxr
 * @date: 2018/6/11 下午4:05
 * @version: V1.0.0
 */
public class AttributeLibraryDto {
    /**
     * 唯一id
     */
    private Long id;

    /**
     * 属性名称
     */
    private String attributeName;

    /**
     * 属性类型 1：基本属性 2：销售属性
     */
    private Integer attributeValueType;

    /**
     * 逻辑删除标识
     */
    private Integer isDelete;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModify;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAttributeName() {
        return attributeName;
    }

    public void setAttributeName(String attributeName) {
        this.attributeName = attributeName;
    }

    public Integer getAttributeValueType() {
        return attributeValueType;
    }

    public void setAttributeValueType(Integer attributeValueType) {
        this.attributeValueType = attributeValueType;
    }

    public Integer getIsDelete() {
        return isDelete;
    }

    public void setIsDelete(Integer isDelete) {
        this.isDelete = isDelete;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModify() {
        return gmtModify;
    }

    public void setGmtModify(Date gmtModify) {
        this.gmtModify = gmtModify;
    }

}

==> goods-center-api-2.5.4-SNAPSHOT-fxr-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/sku/AttributeLibraryDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.sku;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @ClassName: AttributeLibraryDto
 * @Description: 商品属性库（属性名）
 * @author: fxr
 * @date: 2018/6/11 下午4:05
 * @version: V1.0.0
 */
public class AttributeLibraryDto implements Serializable {
    /**
     * 唯一id
     */
    private Long id;

    /**
     * 属性名称
     */
    private String attributeName;

    /**
     * 属性类型 1：基本属性 2：销售属性
     */
    private Integer attributeValueType;

    /**
     * 逻辑删除标识
     */
    private Integer isDelete;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModify;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAttributeName() {
        return attributeName;
    }

    public void setAttributeName(String attributeName) {
        this.attributeName = attributeName;
    }

    public Integer getAttributeValueType() {
        return attributeValueType;
    }

    public void setAttributeValueType(Integer attributeValueType) {
        this.attributeValueType = attributeValueType;
    }

    public Integer getIsDelete() {
        return isDelete;
    }

    public void setIsDelete(Integer isDelete) {
        this.isDelete = isDelete;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModify() {
        return gmtModify;
    }

    public void setGmtModify(Date gmtModify) {
        this.gmtModify = gmtModify;
    }

}
